@@ -70,10 +70,10 @@ print_dust_latex <- function(x, ..., asis=TRUE)
   if (tab_env == "longtable")
   {
     begin <- paste0("\\begin{longtable}[",
-                    substr(x[["justify"]], 1, 1), "]{",
+                    gsub("n", "l", substr(x[["justify"]], 1, 1)), "]{",
                     paste0(col_halign_default$default_halign, collapse = ""), "}\n",
                     if (!is.null(x$caption))
-                      paste("\\caption{", x$caption, "}\\\\")
+                      paste("\\caption{", x$caption, "}")
                     else "", 
                     "\n", label, "\\\\ \n")
     end <- "\\end{longtable}"
@@ -388,7 +388,7 @@ numeric_longtable_newline <- function(n, redefine = FALSE){
 
 needs_parbox <- function(x)
 {
-  !is.na(x$width) | 
+  is.finite(x$width) | 
     (x$halign != x$default_halign) | 
     x$valign != "" | 
     x$merge
@@ -462,7 +462,8 @@ determine_column_width <- function(Joint, x)
     dplyr::select(row, col, width) %>%
     dplyr::group_by(col) %>%
     dplyr::summarise(width = max(width, na.rm=TRUE)) %>%
-    dplyr::ungroup() 
+    dplyr::ungroup() %>%
+    dplyr::mutate(width = ifelse(is.finite(width), width, NA))
 }
 
 determine_row_height <- function(part)
@@ -479,7 +480,7 @@ determine_row_height <- function(part)
     dplyr::group_by(row) %>%
     dplyr::summarise(height = max(height, na.rm=TRUE)) %>%
     dplyr::ungroup() %>%
-    dplyr::mutate(height = ifelse(is.na(height),
+    dplyr::mutate(height = ifelse(!is.finite(height),
                          "", paste0("\\\\[", height, "pt]"))) %>%
     '$'("height") 
 }
@@ -574,4 +575,4 @@ utils::globalVariables(c("halign", "left_border", "right_border",
                          "height_units", "width_units", "table_width",
                          "parbox", "width_by_char", "html_row", 
                          "html_col", "rowspan", "colspan", "value", "col_name",
-                         "col_class", "group"))
\ No newline at end of file
+                         "col_class", "group"))
